@@ -79,7 +79,7 @@ bool smt2_pp_environment::is_indexed_fdecl(func_decl * f) const {
         return false;
     unsigned num = f->get_num_parameters();
     unsigned i;
-    for (i = 0; i < num; i++) {
+    for (i = 0; i < num; ++i) {
         if (f->get_parameter(i).is_int())
             continue;
         if (f->get_parameter(i).is_rational())
@@ -111,7 +111,7 @@ format * smt2_pp_environment::pp_fdecl_params(format * fname, func_decl * f) {
     unsigned num = f->get_num_parameters();
     ptr_buffer<format> fs;
     fs.push_back(fname);
-    for (unsigned i = 0; i < num; i++) {
+    for (unsigned i = 0; i < num; ++i) {
         SASSERT(f->get_parameter(i).is_int() ||
                 f->get_parameter(i).is_rational() ||
                 (f->get_parameter(i).is_ast() && is_func_decl(f->get_parameter(i).get_ast())));
@@ -149,7 +149,7 @@ format * smt2_pp_environment::pp_signature(format * f_name, func_decl * f) {
         f_name = pp_fdecl_params(f_name, f);
     }
     ptr_buffer<format> f_domain;
-    for (unsigned i = 0; i < f->get_arity(); i++)
+    for (unsigned i = 0; i < f->get_arity(); ++i)
         f_domain.push_back(pp_sort(f->get_domain(i)));
     ptr_buffer<format> args;
     args.push_back(f_name);
@@ -417,7 +417,7 @@ format_ns::format * smt2_pp_environment::pp_sort(sort * s) {
     if (get_arutil().is_array(s)) {
         ptr_buffer<format> fs;
         unsigned sz = get_array_arity(s);
-        for (unsigned i = 0; i < sz; i++) {
+        for (unsigned i = 0; i < sz; ++i) {
             fs.push_back(pp_sort(get_array_domain(s, i)));
         }
         fs.push_back(pp_sort(get_array_range(s)));
@@ -443,7 +443,7 @@ format_ns::format * smt2_pp_environment::pp_sort(sort * s) {
         unsigned sz = get_dtutil().get_datatype_num_parameter_sorts(s);
         if (sz > 0) {
             ptr_buffer<format> fs;            
-            for (unsigned i = 0; i < sz; i++) {
+            for (unsigned i = 0; i < sz; ++i) {
                 fs.push_back(pp_sort(get_dtutil().get_datatype_parameter_sort(s, i)));
             }
             return mk_seq1(m, fs.begin(), fs.end(), f2f(), name);
@@ -702,7 +702,7 @@ class smt2_printer {
             ((f_info.m_depth >= m_pp_max_depth) ||
              ((f_info.m_weight >= m_pp_min_alias_size || is_quantifier(t)) && m_soccs.is_shared(t)))) {
             symbol a = next_alias();
-            TRACE("smt2_pp", tout << "a: " << a << " depth: " << f_info.m_depth << ", weight: " << f_info.m_weight
+            TRACE(smt2_pp, tout << "a: " << a << " depth: " << f_info.m_depth << ", weight: " << f_info.m_weight
                   << ", lvl: " << f_info.m_lvl << " t: #" << t->get_id() << "\n" << mk_ll_pp(t, m())
                   << ", is-shared: " << m_soccs.is_shared(t) << "\n";);
             register_alias(t, f, f_info.m_lvl, a);
@@ -800,11 +800,11 @@ class smt2_printer {
         unsigned sz     = m_aliased_exprs.size();
         SASSERT(old_sz <= sz);
         num_lets = sz - old_sz;
-        TRACE("pp_let", tout << "old_sz: " << old_sz << ", sz: " << sz << "\n";);
+        TRACE(pp_let, tout << "old_sz: " << old_sz << ", sz: " << sz << "\n";);
         if (old_sz == sz)
             return f;
         vector<ptr_vector<format> > decls;
-        for (unsigned i = old_sz; i < sz; i++) {
+        for (unsigned i = old_sz; i < sz; ++i) {
             unsigned lvl    = m_aliased_lvls_names[i].first;
             symbol   f_name = m_aliased_lvls_names[i].second;
             format * f_def[1] = { m_aliased_pps.get(i) };
@@ -812,7 +812,7 @@ class smt2_printer {
             ptr_vector<format> & lvl_decls = decls[lvl];
             lvl_decls.push_back(mk_seq1<format**, f2f>(m(), f_def, f_def+1, f2f(), f_name.str()));
         }
-        TRACE("pp_let", tout << "decls.size(): " << decls.size() << "\n";);
+        TRACE(pp_let, tout << "decls.size(): " << decls.size() << "\n";);
         ptr_buffer<format> buf;
         unsigned num_op = 0;
         for (ptr_vector<format> & lvl_decls : decls) {
@@ -824,11 +824,11 @@ class smt2_printer {
             buf.push_back(mk_string(m(), "(let "));
             buf.push_back(mk_indent(m(), 5, mk_seq5(m(), lvl_decls.begin(), lvl_decls.end(), f2f())));
         }
-        TRACE("pp_let", tout << "num_op: " << num_op << "\n";);
+        TRACE(pp_let, tout << "num_op: " << num_op << "\n";);
         if (num_op == 0)
             return f;
         buf.push_back(mk_indent(m(), SMALL_INDENT, mk_compose(m(), mk_line_break(m()), f)));
-        for (unsigned i = 0; i < num_op; i++)
+        for (unsigned i = 0; i < num_op; ++i)
             buf.push_back(mk_string(m(), ")"));
         return mk_compose(m(), buf.size(), buf.data());
     }
@@ -841,7 +841,7 @@ class smt2_printer {
     void begin_scope() {
         SASSERT(m_aliased_exprs.size() == m_aliased_pps.size());
         SASSERT(m_aliased_exprs.size() == m_aliased_lvls_names.size());
-        TRACE("pp_scope", tout << "[begin-scope] sz: " << m_aliased_exprs.size() << ", m_root: " << m_root << "\n";);
+        TRACE(pp_scope, tout << "[begin-scope] sz: " << m_aliased_exprs.size() << ", m_root: " << m_root << "\n";);
         m_scopes.push_back(scope(m_aliased_exprs.size(), m_next_alias_idx, m_root));
         unsigned lvl = m_scopes.size();
         while (lvl >= m_expr2alias_stack.size())
@@ -851,7 +851,7 @@ class smt2_printer {
     }
 
     void end_scope() {
-        TRACE("pp_scope", tout << "[end-scope] before sz: " << m_aliased_exprs.size() << ", m_root: " << m_root << "\n";);
+        TRACE(pp_scope, tout << "[end-scope] before sz: " << m_aliased_exprs.size() << ", m_root: " << m_root << "\n";);
         m_expr2alias->reset();
         scope & s = m_scopes.back();
         unsigned old_sz = s.m_aliased_exprs_lim;
@@ -864,12 +864,12 @@ class smt2_printer {
         m_aliased_exprs.shrink(old_sz);
         m_aliased_pps.shrink(old_sz);
         m_aliased_lvls_names.shrink(old_sz);
-        TRACE("pp_scope", tout << "[end-scope] after sz: " << m_aliased_exprs.size() << ", m_root: " << m_root << "\n";);
+        TRACE(pp_scope, tout << "[end-scope] after sz: " << m_aliased_exprs.size() << ", m_root: " << m_root << "\n";);
     }
 
     void register_var_names(quantifier * q) {
         unsigned num_decls = q->get_num_decls();
-        for (unsigned i = 0; i < num_decls; i++) {
+        for (unsigned i = 0; i < num_decls; ++i) {
             symbol name = ensure_quote_sym(q->get_decl_name(i));
             if (name.is_numerical()) {
                 unsigned idx = 1;
@@ -887,7 +887,7 @@ class smt2_printer {
 
     void register_var_names(unsigned n) {
         unsigned idx = 1;
-        for (unsigned i = 0; i < n; i++) {
+        for (unsigned i = 0; i < n; ++i) {
             symbol name = next_name("x", idx);            
             SASSERT(!m_var_names_set.contains(name));
             m_var_names.push_back(name);
@@ -900,7 +900,7 @@ class smt2_printer {
     }
 
     void unregister_var_names(unsigned num_decls) {
-        for (unsigned i = 0; i < num_decls; i++) {
+        for (unsigned i = 0; i < num_decls; ++i) {
             symbol s = m_var_names.back();
             m_var_names.pop_back();
             m_var_names_set.erase(s);
@@ -911,7 +911,7 @@ class smt2_printer {
         ptr_buffer<format> buf;
         SASSERT(num_decls <= m_var_names.size());
         symbol * it = m_var_names.end() - num_decls;
-        for (unsigned i = 0; i < num_decls; i++, it++) {
+        for (unsigned i = 0; i < num_decls; ++i, ++it) {
             format * fs[1] = { m_env.pp_sort(srts[i]) };
             std::string var_name;
             if (is_smt2_quoted_symbol (*it)) {
@@ -1110,7 +1110,7 @@ public:
             var_prefix = "_a";
         }
         unsigned idx = 0;
-        for (unsigned i = 0; i < num; i++) {
+        for (unsigned i = 0; i < num; ++i) {
             symbol name = next_name(var_prefix, idx);
             name = ensure_quote_sym(name);
             var_names.push_back(name);
@@ -1136,7 +1136,7 @@ public:
         format * args[3];
         args[0] = fname;
         ptr_buffer<format> buf;
-        for (unsigned i = 0; i < arity; i++) {
+        for (unsigned i = 0; i < arity; ++i) {
             buf.push_back(m_env.pp_sort(f->get_domain(i)));
         }
         args[1] = mk_seq5<format**, f2f>(m(), buf.begin(), buf.end(), f2f());
