@@ -170,7 +170,7 @@ bool proof_checker::check1_spc(proof* p, expr_ref_vector& side_conditions) {
                 }
             }
             expr_ref rewrite_cond(m);
-            rewrite_cond = m.mk_or(rewrite_eq.size(), rewrite_eq.c_ptr());
+            rewrite_cond = m.mk_or(rewrite_eq);
             side_conditions.push_back(rewrite_cond.get());
             return true;
         }
@@ -301,7 +301,7 @@ bool proof_checker::check1_basic(proof* p, expr_ref_vector& side_conditions) {
         return false;
     }
     case PR_MONOTONICITY: {
-        TRACE("proof_checker", tout << mk_bounded_pp(p, m, 3) << "\n";);
+        TRACE(proof_checker, tout << mk_bounded_pp(p, m, 3) << "\n";);
         if (match_fact(p, fact) &&
             match_binary(fact, d1, t1, t2) &&
             match_app(t1, f1, terms1) &&
@@ -431,7 +431,7 @@ bool proof_checker::check1_basic(proof* p, expr_ref_vector& side_conditions) {
                 }
             }
             expr_ref rewrite_cond(m);
-            rewrite_cond = m.mk_or(rewrite_eq.size(), rewrite_eq.data());
+            rewrite_cond = m.mk_or(rewrite_eq);
             side_conditions.push_back(rewrite_cond.get());
             return true;
         }
@@ -530,7 +530,7 @@ bool proof_checker::check1_basic(proof* p, expr_ref_vector& side_conditions) {
                     found = match_negated(ors[j].get(), hypotheses[i].get());
                 }
                 if (!found) {
-                    TRACE("pr_lemma_bug",
+                    TRACE(pr_lemma_bug,
                           tout << "i: " << i << "\n";
                           tout << "ORs:\n" << ors << "\n";
                           tout << "HYPOTHESIS:\n" << hypotheses << "\n";
@@ -538,7 +538,7 @@ bool proof_checker::check1_basic(proof* p, expr_ref_vector& side_conditions) {
                     UNREACHABLE();
                     return false;
                 }
-                TRACE("proof_checker", tout << "Matched:\n";
+                TRACE(proof_checker, tout << "Matched:\n";
                       ast_ll_pp(tout, m, hypotheses[i].get());
                       ast_ll_pp(tout, m, ors[j-1].get()););
             }
@@ -575,9 +575,9 @@ bool proof_checker::check1_basic(proof* p, expr_ref_vector& side_conditions) {
                     }
                 }
                 if (!found) {
-                    TRACE("pr_unit_bug",
+                    TRACE(pr_unit_bug,
                           tout << "Parents:\n";
-                          for (unsigned i = 0; i < proofs.size(); i++) {
+                          for (unsigned i = 0; i < proofs.size(); ++i) {
                               expr* p = nullptr;
                               match_fact(proofs.get(i), p);
                               tout << mk_pp(p, m) << "\n";
@@ -791,7 +791,7 @@ bool proof_checker::check1_basic(proof* p, expr_ref_vector& side_conditions) {
                 premise = vs(premise, sub.size(), sub.data());
             }
             fmls.push_back(premise.get());
-            TRACE("proof_checker",
+            TRACE(proof_checker,
                   tout << mk_pp(premise.get(), m) << "\n";
                   for (unsigned j = 0; j < sub.size(); ++j) {
                       tout << mk_pp(sub[j], m) << " ";
@@ -819,7 +819,7 @@ bool proof_checker::check1_basic(proof* p, expr_ref_vector& side_conditions) {
             fmls[i] = premise1;
         }
         fmls[0] = premise0;
-        premise0 = m.mk_or(fmls.size(), fmls.data());
+        premise0 = m.mk_or(fmls);
         if (is_forall(conclusion)) {
             quantifier* q = to_quantifier(conclusion);
             premise0 = m.mk_iff(premise0, q->get_expr());
@@ -861,7 +861,7 @@ void proof_checker::set_false(expr_ref& e, unsigned position, expr_ref& lit) {
         args.append(a->get_num_args(), a->get_args());
         lit = args[position].get();
         args[position] = m.mk_false();
-        e = m.mk_or(args.size(), args.data());
+        e = m.mk_or(args);
     }
     else if (m.is_implies(e, body, head)) {
         expr* const* heads = &head;
@@ -880,14 +880,14 @@ void proof_checker::set_false(expr_ref& e, unsigned position, expr_ref& lit) {
             args.append(num_heads, heads);
             lit = args[position].get();
             args[position] = m.mk_false();
-            e = m.mk_implies(body, m.mk_or(args.size(), args.data()));
+            e = m.mk_implies(body, m.mk_or(args));
         }
         else {
             position -= num_heads;
             args.append(num_bodies, bodies);
             lit = m.mk_not(args[position].get());
             args[position] = m.mk_true();
-            e = m.mk_implies(m.mk_and(args.size(), args.data()), head);
+            e = m.mk_implies(m.mk_and(args), head);
         }
     }
     else if (position == 0) {
@@ -1151,7 +1151,7 @@ void proof_checker::get_hypotheses(proof* p, expr_ref_vector& ante) {
             SASSERT(match_nil(h));
         }
     }
-    TRACE("proof_checker",
+    TRACE(proof_checker,
           {
               ast_ll_pp(tout << "Getting hypotheses from: ", m, p);
               tout << "Found hypotheses:\n";
@@ -1236,7 +1236,7 @@ void proof_checker::dump_proof(proof const* pr) {
     expr * consequent = m.get_fact(pr);
     unsigned num      = m.get_num_parents(pr);
     ptr_buffer<expr> antecedents;
-    for (unsigned i = 0; i < num; i++) {
+    for (unsigned i = 0; i < num; ++i) {
         proof * a = m.get_parent(pr, i);
         SASSERT(m.has_fact(a));
         antecedents.push_back(m.get_fact(a));
@@ -1252,7 +1252,7 @@ void proof_checker::dump_proof(unsigned num_antecedents, expr * const * antecede
     pp.set_benchmark_name("lemma");
     pp.set_status("unsat");
     pp.set_logic(symbol(m_logic.c_str()));
-    for (unsigned i = 0; i < num_antecedents; i++)
+    for (unsigned i = 0; i < num_antecedents; ++i)
         pp.add_assumption(antecedents[i]);
     expr_ref n(m);
     n = m.mk_not(consequent);
@@ -1389,15 +1389,15 @@ bool proof_checker::check_arith_proof(proof* p) {
     }
 
     unsigned num_parents = m.get_num_parents(p);
-    for (unsigned i = 0; i < num_parents; i++) {
+    for (unsigned i = 0; i < num_parents; ++i) {
         proof * a = m.get_parent(p, i);
         SASSERT(m.has_fact(a));
         if (!check_arith_literal(true, to_app(m.get_fact(a)), coeffs[offset++], sum, is_strict)) {
             return false;
         }
     }
-    TRACE("proof_checker", 
-          for (unsigned i = 0; i < num_parents; i++) 
+    TRACE(proof_checker, 
+          for (unsigned i = 0; i < num_parents; ++i) 
               tout << coeffs[i] << " * " << mk_bounded_pp(m.get_fact(m.get_parent(p, i)), m) << "\n";
           tout << "fact:" << mk_bounded_pp(fact, m) << "\n";);
     
