@@ -44,6 +44,7 @@ namespace lp {
         dioph_eq            m_dio;  
         int_gcd_test        m_gcd;
         unsigned            m_initial_dio_calls_period;
+        unsigned            m_patch_period = 1;
         
         bool column_is_int_inf(unsigned j) const {
             return lra.column_is_int(j) && (!lia.value_is_int(j));
@@ -52,6 +53,8 @@ namespace lp {
         imp(int_solver& lia): lia(lia), lra(lia.lra), lrac(lia.lrac), m_hnf_cutter(lia), m_dio(lia), m_gcd(lia) {
             m_hnf_cut_period = settings().hnf_cut_period();
             m_initial_dio_calls_period = settings().dio_calls_period();
+            m_patch_period = settings().m_int_patch_period;
+            SASSERT(m_patch_period > 0);
         } 
 
         bool has_lower(unsigned j) const {
@@ -127,7 +130,7 @@ namespace lp {
 
         bool all_columns_are_integral() const {
             return true; // otherwise it never returns true!
-            for (lpvar j = 0; j < lra.number_of_vars(); j++)
+            for (lpvar j = 0; j < lra.number_of_vars(); ++j)
                 if (!lra.column_is_int(j))
                     return false;
             return true;
@@ -156,6 +159,10 @@ namespace lp {
                     try_patch_column(v, c.var(), delta_plus);
         }
         
+        bool should_patch() {
+            return m_number_of_calls % m_patch_period == 0;
+        }
+
         lia_move patch_basic_columns() {
             lia.settings().stats().m_patches++;
             lra.remove_fixed_vars_from_base();
@@ -244,7 +251,7 @@ namespace lp {
                 return lia_move::undef;
 
             ++m_number_of_calls;
-            if (r == lia_move::undef) r = patch_basic_columns();
+            if (r == lia_move::undef && should_patch()) r = patch_basic_columns();
             if (r == lia_move::undef && should_find_cube()) r = int_cube(lia)();
             if (r == lia_move::undef) lra.move_non_basic_columns_to_bounds();
             if (r == lia_move::undef && should_hnf_cut()) r = hnf_cut();
@@ -449,14 +456,14 @@ namespace lp {
     
     std::ostream& int_solver::display_inf_rows(std::ostream& out) const {
         unsigned num = lra.A_r().column_count();
-        for (unsigned v = 0; v < num; v++) {
+        for (unsigned v = 0; v < num; ++v) {
             if (column_is_int(v) && !get_value(v).is_int()) {
                 display_column(out, v);
             }
         }
 
         num = 0;
-        for (unsigned i = 0; i < lra.A_r().row_count(); i++) {
+        for (unsigned i = 0; i < lra.A_r().row_count(); ++i) {
             unsigned j = lrac.m_r_basis[i];
             if (column_is_int_inf(j)) {
                 num++;
