@@ -239,6 +239,7 @@ public:
     unsigned         column_number_threshold_for_using_lu_in_lar_solver = 4000;
     unsigned         m_int_gomory_cut_period = 4;
     unsigned         m_int_find_cube_period = 4;
+    unsigned         m_int_patch_period = 1;
 private:
     unsigned         m_hnf_cut_period = 4;
     bool             m_int_run_gcd_test = true;
@@ -350,7 +351,7 @@ template <typename T, typename K >
 bool vectors_are_equal_(const T & a, const K &b) {
     if (a.size() != b.size())
         return false;
-    for (unsigned i = 0; i < a.size(); i++){
+    for (unsigned i = 0; i < a.size(); ++i){
         if (a[i] != b[i]) {
             return false;
         }
