@@ -133,16 +133,16 @@ public:
 
     void add_to_allocated(nex* r) {
         m_allocated.push_back(r);
-        CTRACE("grobner_stats_d", m_allocated.size() % 1000 == 0, tout << "m_allocated.size() = " << m_allocated.size() << "\n";);
+        CTRACE(grobner_stats_d, m_allocated.size() % 1000 == 0, tout << "m_allocated.size() = " << m_allocated.size() << "\n";);
     }
 
     // NSB: we can use region allocation, but still need to invoke destructor 
     // because of 'rational' (and m_children in nex_mul unless we get rid of this)
     void pop(unsigned sz) {
-        for (unsigned j = sz; j < m_allocated.size(); j++)
+        for (unsigned j = sz; j < m_allocated.size(); ++j)
             dealloc(m_allocated[j]);
         m_allocated.resize(sz);
-        TRACE("grobner_stats_d", tout << "m_allocated.size() = " << m_allocated.size() << "\n";);
+        TRACE(grobner_stats_d, tout << "m_allocated.size() = " << m_allocated.size() << "\n";);
     }
 
     void clear() {
