@@ -35,7 +35,7 @@ public:
         for (auto c: cs) {
             m_cs[i++] = c;
         }
-        for (; i < 4; i++) {
+        for (; i < 4; ++i) {
             m_cs[i] = nullptr;
         }
     }
@@ -68,7 +68,7 @@ class var_eqs {
         stats() { memset(this, 0, sizeof(*this)); }
     };
 
-    T*                                m_merge_handler;    
+    T*                                m_merge_handler = nullptr;    
     union_find<var_eqs>               m_uf;
     lp::incremental_vector<std::pair<signed_var, signed_var>> m_trail;
     vector<svector<eq_edge>>          m_eqs;    // signed_var.index() -> the edges adjacent to signed_var.index()
@@ -81,7 +81,7 @@ class var_eqs {
         
     mutable stats m_stats;
 public:    
-    var_eqs(): m_merge_handler(nullptr), m_uf(*this) {}    
+    var_eqs(): m_uf(*this) {}    
     /**
        \brief push a scope    */
     void push() {
