@@ -16,8 +16,7 @@ Author:
 Revision History:
 
 --*/
-#ifndef SUBPAVING_MPFX_H_
-#define SUBPAVING_MPFX_H_
+#pragma once
 
 #include "math/subpaving/subpaving_t.h"
 #include "util/mpfx.h"
@@ -42,4 +41,3 @@ typedef context_t<config_mpfx> context_mpfx;
 
 };
 
-#endif
