@@ -50,7 +50,10 @@ namespace datalog {
 
         sort_domain(sort_kind k, context & ctx, sort * s)
             : m_kind(k), m_sort(s, ctx.get_manager()) {
-                m_limited_size = ctx.get_decl_util().try_get_size(s, m_size);
+                auto opt_size = ctx.get_decl_util().try_get_size(s);
+                m_limited_size = opt_size.has_value();
+                if (m_limited_size)
+                    m_size = *opt_size;
         }
     public:
         virtual ~sort_domain() = default;
@@ -638,7 +641,7 @@ namespace datalog {
         SASSERT(is_fact(head));
         relation_fact fact(get_manager());
         unsigned n = head->get_num_args();
-        for (unsigned i = 0; i < n; i++) {
+        for (unsigned i = 0; i < n; ++i) {
             fact.push_back(to_app(head->get_arg(i)));
         }
         add_fact(head->get_decl(), fact);
