@@ -82,7 +82,7 @@ namespace smt {
         unsigned num_args = n1->get_num_args();
         if (num_args != n2->get_num_args())
             return false;
-        for (unsigned j = 0; j < num_args; j++) {
+        for (unsigned j = 0; j < num_args; ++j) {
             enode * arg1 = n1->get_arg(j)->get_root();
             enode * arg2 = n2->get_arg(j)->get_root();
             if (arg1 == arg2)
