@@ -25,6 +25,7 @@ Author:
 #include "smt/smt_parallel.h"
 #include "smt/smt_lookahead.h"
 #include "solver/solver_preprocess.h"
+#include "params/smt_parallel_params.hpp"
 
 #include <cmath>
 #include <mutex>
@@ -63,6 +64,50 @@ namespace smt {
 
 namespace smt {
 
+    void parallel::sls_worker::run() {
+        ptr_vector<expr> assertions;
+        p.ctx.get_assertions(assertions);
+        for (expr* e : assertions)
+            m_sls->assert_expr(m_g2l(e));
+
+        lbool res = l_undef;
+        try {
+            if (!m.inc())
+                return;
+            res = m_sls->check();
+        } catch (z3_exception& ex) {
+            // Cancellation is normal in portfolio mode
+            if (m.limit().is_canceled()) {
+                IF_VERBOSE(1, verbose_stream() << "SLS worker canceled\n");
+                return;
+            }
+
+            if (strstr(ex.what(), "unsupported for sls") != nullptr) {
+                IF_VERBOSE(1, verbose_stream() << "SLS opted out: " << ex.what() << "\n");
+                return;
+            }
+
+            // Anything else is a real error
+            IF_VERBOSE(1, verbose_stream() << "SLS threw exception: " << ex.what() << "\n");
+            b.set_exception(ex.what());
+            return;
+        }
+
+        if (res == l_true) {            
+            model_ref mdl = m_sls->get_model();
+            b.set_sat(m_l2g, *mdl);
+        }
+    }
+
+    void parallel::sls_worker::cancel() {
+        IF_VERBOSE(1, verbose_stream() << " SLS WORKER cancelling\n");
+        m.limit().cancel();
+    }
+
+    void parallel::sls_worker::collect_statistics(::statistics &st) const {
+        m_sls->collect_statistics(st);
+    }
+
     void parallel::worker::run() {
         search_tree::node<cube_config> *node = nullptr;
         expr_ref_vector cube(m);
@@ -115,13 +160,13 @@ namespace smt {
                     b.set_unsat(m_l2g, unsat_core);
                     return;
                 }
-                // report assumptions used in unsat core, so they can be used in final core
-                for (expr *e : unsat_core)
-                    if (asms.contains(e))
-                        b.report_assumption_used(m_l2g, e);  
 
                 LOG_WORKER(1, " found unsat cube\n");
                 b.backtrack(m_l2g, unsat_core, node);
+
+                if (m_config.m_share_conflicts)
+                    b.collect_clause(m_l2g, id, mk_not(mk_and(unsat_core)));
+
                 break;
             }
             }
@@ -131,33 +176,49 @@ namespace smt {
     }
 
     parallel::worker::worker(unsigned id, parallel &p, expr_ref_vector const &_asms)
-        : id(id), p(p), b(p.m_batch_manager), m_smt_params(p.ctx.get_fparams()), asms(m), m_g2l(p.ctx.m, m),
+        : id(id), p(p), b(p.m_batch_manager), asms(m), m_smt_params(p.ctx.get_fparams()), m_g2l(p.ctx.m, m),
           m_l2g(m, p.ctx.m) {
         for (auto e : _asms)
             asms.push_back(m_g2l(e));
         LOG_WORKER(1, " created with " << asms.size() << " assumptions\n");
-        m_smt_params.m_preprocess = false;
         ctx = alloc(context, m, m_smt_params, p.ctx.get_params());
+        ctx->set_logic(p.ctx.m_setup.get_logic());
         context::copy(p.ctx, *ctx, true);
         ctx->set_random_seed(id + m_smt_params.m_random_seed);
         // don't share initial units
         ctx->pop_to_base_lvl();
         m_num_shared_units = ctx->assigned_literals().size();
         m_num_initial_atoms = ctx->get_num_bool_vars();
+        ctx->get_fparams().m_preprocess = false;  // avoid preprocessing lemmas that are exchanged
+
+        smt_parallel_params pp(p.ctx.m_params);
+        m_config.m_inprocessing = pp.inprocessing();
+    }
+
+    parallel::sls_worker::sls_worker(parallel& p)
+        : p(p), b(p.m_batch_manager), m(), m_g2l(p.ctx.m, m), m_l2g(m, p.ctx.m) {
+        IF_VERBOSE(1, verbose_stream() << "Initialized SLS portfolio thread\n");
+        m_params.append(p.ctx.m_params);
+        m_sls = alloc(sls::smt_solver, m, m_params);
     }
 
     void parallel::worker::share_units() {
         // Collect new units learned locally by this worker and send to batch manager
-        ctx->pop_to_base_lvl();
+        
         unsigned sz = ctx->assigned_literals().size();
         for (unsigned j = m_num_shared_units; j < sz; ++j) {  // iterate only over new literals since last sync
             literal lit = ctx->assigned_literals()[j];
+
+            // filter by assign level: do not pop to base level as this destroys the current search state
+            if (ctx->get_assign_level(lit) > ctx->m_base_lvl)
+                continue;
+
             if (!ctx->is_relevant(lit.var()) && m_config.m_share_units_relevant_only)
                 continue;
 
             if (m_config.m_share_units_initial_only && lit.var() >= m_num_initial_atoms) {
-                LOG_WORKER(2, " Skipping non-initial unit: " << lit.var() << "\n");
-                continue;  // skip non-iniial atoms if configured to do so
+                LOG_WORKER(4, " Skipping non-initial unit: " << lit.var() << "\n");
+                continue;  // skip non-initial atoms if configured to do so
             }
 
             expr_ref e(ctx->bool_var2expr(lit.var()), ctx->m);  // turn literal into a Boolean expression
@@ -260,15 +321,18 @@ namespace smt {
         vector<cube_config::literal> g_core;
         for (auto c : core) {
             expr_ref g_c(l2g(c), m);
-            if (!is_assumption(g_c))
-                g_core.push_back(expr_ref(l2g(c), m));
+            g_core.push_back(expr_ref(l2g(c), m));
         }
         m_search_tree.backtrack(node, g_core);
 
         IF_VERBOSE(1, m_search_tree.display(verbose_stream() << bounded_pp_exprs(core) << "\n"););
         if (m_search_tree.is_closed()) {
+            IF_VERBOSE(1, verbose_stream() << "Search tree closed, setting UNSAT\n");
             m_state = state::is_unsat;
-            cancel_workers();
+            SASSERT(p.ctx.m_unsat_core.empty());
+            for (auto e : m_search_tree.get_core_from_root())
+               p.ctx.m_unsat_core.push_back(e);
+            cancel_background_threads();
         }
     }
 
@@ -285,6 +349,8 @@ namespace smt {
         // node->get_status() == status::active
         // and depth is 'high' enough
         // then ignore split, and instead set the status of node to open.
+        ++m_stats.m_num_cubes;
+        m_stats.m_max_cube_depth = std::max(m_stats.m_max_cube_depth, node->depth() + 1);
         m_search_tree.split(node, lit, nlit);
     }
 
@@ -303,7 +369,7 @@ namespace smt {
         // iterate over new clauses and assert them in the local context
         for (expr *e : new_clauses) {
             ctx->assert_expr(e);
-            LOG_WORKER(2, " asserting shared clause: " << mk_bounded_pp(e, m, 3) << "\n");
+            LOG_WORKER(4, " asserting shared clause: " << mk_bounded_pp(e, m, 3) << "\n");
         }
     }
 
@@ -374,7 +440,7 @@ namespace smt {
             return;
         m_state = state::is_sat;
         p.ctx.set_model(m.translate(l2g));
-        cancel_workers();
+        cancel_background_threads();
     }
 
     void parallel::batch_manager::set_unsat(ast_translation &l2g, expr_ref_vector const &unsat_core) {
@@ -388,7 +454,7 @@ namespace smt {
         SASSERT(p.ctx.m_unsat_core.empty());
         for (expr *e : unsat_core)
             p.ctx.m_unsat_core.push_back(l2g(e));
-        cancel_workers();
+        cancel_background_threads();
     }
 
     void parallel::batch_manager::set_exception(unsigned error_code) {
@@ -398,7 +464,7 @@ namespace smt {
             return;
         m_state = state::is_exception_code;
         m_exception_code = error_code;
-        cancel_workers();
+        cancel_background_threads();
     }
 
     void parallel::batch_manager::set_exception(std::string const &msg) {
@@ -408,12 +474,7 @@ namespace smt {
             return;
         m_state = state::is_exception_msg;
         m_exception_msg = msg;
-        cancel_workers();
-    }
-
-    void parallel::batch_manager::report_assumption_used(ast_translation &l2g, expr *assumption) {
-        std::scoped_lock lock(mux);
-        p.m_assumptions_used.insert(l2g(assumption));
+        cancel_background_threads();
     }
 
     lbool parallel::batch_manager::get_result() const {
@@ -422,16 +483,7 @@ namespace smt {
         switch (m_state) {
         case state::is_running:  // batch manager is still running, but all threads have processed their cubes, which
                                  // means all cubes were unsat
-            if (!m_search_tree.is_closed())
-                throw default_exception("inconsistent end state");
-            if (!p.m_assumptions_used.empty()) {
-                // collect unsat core from assumptions used, if any --> case when all cubes were unsat, but depend on
-                // nonempty asms, so we need to add these asms to final unsat core
-                SASSERT(p.ctx.m_unsat_core.empty());
-                for (auto a : p.m_assumptions_used)
-                    p.ctx.m_unsat_core.push_back(a);
-            }
-            return l_false;
+            throw default_exception("inconsistent end state");
         case state::is_unsat:
             return l_false;
         case state::is_sat:
@@ -486,6 +538,7 @@ namespace smt {
     }
 
     lbool parallel::operator()(expr_ref_vector const &asms) {
+        IF_VERBOSE(1, verbose_stream() << "Parallel SMT with " << num_threads << " threads\n";);
         ast_manager &m = ctx.m;
 
         if (m.has_trace_stream())
@@ -496,30 +549,38 @@ namespace smt {
             scoped_clear(parallel &p) : p(p) {}
             ~scoped_clear() {
                 p.m_workers.reset();
-                p.m_assumptions_used.reset();
-                p.m_assumptions.reset();
+                p.m_sls_worker = nullptr;
             }
         };
         scoped_clear clear(*this);
 
         m_batch_manager.initialize();
         m_workers.reset();
-        for (auto e : asms)
-            m_assumptions.insert(e);
+
+        smt_parallel_params pp(ctx.m_params);
+        m_should_run_sls = pp.sls();
+        
         scoped_limits sl(m.limit());
         flet<unsigned> _nt(ctx.m_fparams.m_threads, 1);
         SASSERT(num_threads > 1);
         for (unsigned i = 0; i < num_threads; ++i)
             m_workers.push_back(alloc(worker, i, *this, asms));
-
         for (auto w : m_workers)
             sl.push_child(&(w->limit()));
+        if (m_should_run_sls) {
+            m_sls_worker = alloc(sls_worker, *this);
+            sl.push_child(&(m_sls_worker->limit()));
+        }
 
         // Launch threads
-        vector<std::thread> threads(num_threads);
-        for (unsigned i = 0; i < num_threads; ++i) {
+        vector<std::thread> threads;
+        threads.resize(m_should_run_sls ? num_threads + 1 : num_threads); // +1 for sls worker
+        for (unsigned i = 0; i < num_threads; ++i)
             threads[i] = std::thread([&, i]() { m_workers[i]->run(); });
-        }
+        
+        // the final thread runs the sls worker
+        if (m_should_run_sls)
+            threads[num_threads] = std::thread([&]() { m_sls_worker->run(); });
 
         // Wait for all threads to finish
         for (auto &th : threads)
@@ -528,6 +589,8 @@ namespace smt {
         for (auto w : m_workers)
             w->collect_statistics(ctx.m_aux_stats);
         m_batch_manager.collect_statistics(ctx.m_aux_stats);
+        if (m_should_run_sls)
+            m_sls_worker->collect_statistics(ctx.m_aux_stats);
 
         return m_batch_manager.get_result();
     }
