@@ -20,6 +20,7 @@ Author:
 #include "ast/rewriter/bit_blaster/bit_blaster.h"
 #include "model/char_factory.h"
 #include "smt/smt_theory.h"
+#include <optional>
 
 namespace smt {
 
@@ -49,7 +50,7 @@ namespace smt {
         expr_ref_vector const& get_ebits(theory_var v);
         bool has_bits(theory_var v) const;
         void init_bits(theory_var v);
-        bool get_char_value(theory_var v, unsigned& c);        
+        std::optional<unsigned> get_char_value(theory_var v) const;        
         void enforce_ackerman(theory_var v, theory_var w);
         void enforce_value_bound(theory_var v);
         void enforce_bits();
@@ -75,7 +76,7 @@ namespace smt {
         bool internalize_atom(app * atom, bool gate_ctx) override;
         bool internalize_term(app * term) override;
         void display(std::ostream& out) const override {}
-        final_check_status final_check_eh() override { return final_check() ? FC_DONE : FC_CONTINUE; }
+        final_check_status final_check_eh(unsigned) override { return final_check() ? FC_DONE : FC_CONTINUE; }
         void init_model(model_generator & mg) override;
         model_value_proc * mk_value(enode * n, model_generator & mg) override;
         void collect_statistics(::statistics& st) const override;
