@@ -63,7 +63,11 @@ namespace smt {
 
         void init_search_eh() override;
 
-        final_check_status final_check_eh() override;
+        final_check_status final_check_eh(unsigned) override;
+
+        unsigned num_final_check_levels() const override {
+            return 2;
+        }
 
         bool is_shared(theory_var v) const override;
     
@@ -93,6 +97,7 @@ namespace smt {
         bool get_upper(enode* n, expr_ref& r);
         bool get_lower(enode* n, rational& r, bool& is_strict);
         bool get_upper(enode* n, rational& r, bool& is_strict);
+        void solve_for(vector<solution>& s) override;
                 
         void display(std::ostream & out) const override;
         
