@@ -77,7 +77,6 @@ namespace smt {
             atom(bool_var bv, int pos, int neg) : 
                 m_bvar(bv), m_true(false),
                 m_pos(pos), m_neg(neg) {}
-            ~atom() {}
             bool_var get_bool_var() const { return m_bvar; }
             void assign_eh(bool is_true) { m_true = is_true; }
             int get_asserted_edge() const { return this->m_true?m_pos:m_neg; }
@@ -246,7 +245,7 @@ namespace smt {
             m_arith_eq_adapter.init_search_eh();
         }
 
-        final_check_status final_check_eh() override;
+        final_check_status final_check_eh(unsigned level) override;
 
         bool is_shared(th_var v) const override {
             return false;
@@ -324,11 +323,11 @@ namespace smt {
 
         void new_eq_or_diseq(bool is_eq, th_var v1, th_var v2, justification& eq_just);
         
-        bool is_int(theory_var v) const { return a.is_int(get_enode(v)->get_owner()); }
+        bool is_int(theory_var v) const { return a.is_int(get_enode(v)->get_expr()); }
 
         th_var get_zero(sort* s) { return a.is_int(s) ? m_izero : m_rzero; }
 
-        th_var get_zero(expr* e) { return get_zero(get_manager().get_sort(e)); }
+        th_var get_zero(expr* e) { return get_zero(e->get_sort()); }
 
         void init_zero();
 
