@@ -48,7 +48,7 @@ class bv2real_util {
     struct bvr_hash {
         unsigned operator()(bvr_sig const& x) const {
             unsigned a[3] = { x.m_msz, x.m_nsz, x.m_d.hash() };            
-            return string_hash((char const*)a, 12, x.m_r.hash());
+            return string_hash(std::string_view((char const*)a, 12), x.m_r.hash());
         }
     };
 
@@ -65,6 +65,7 @@ class bv2real_util {
     rational m_default_divisor;
     rational m_max_divisor;
     unsigned m_max_num_bits;
+    uint64_t m_max_memory;
 
     class contains_bv2real_proc;
 
@@ -81,6 +82,8 @@ public:
 
     bool contains_bv2real(expr* e) const;
 
+    bool memory_exceeded() const;
+
     bool mk_bv2real(expr* s, expr* t, rational& d, rational& r, expr_ref& result);
     expr* mk_bv2real_c(expr* s, expr* t, rational const& d, rational const& r);
     expr* mk_bv2real(expr* n, expr* m) { return mk_bv2real_c(n, m, default_divisor(), default_root()); }
