@@ -32,11 +32,8 @@ class progress_callback;
 typedef ptr_buffer<goal> goal_buffer;
 
 class tactic : public user_propagator::core {
-    unsigned m_ref_count;
+    unsigned m_ref_count = 0;
 public:
-    tactic():m_ref_count(0) {}
-    virtual ~tactic() {}
-
     void inc_ref() { m_ref_count++; }
     void dec_ref() { SASSERT(m_ref_count > 0); m_ref_count--; if (m_ref_count == 0) dealloc(this); }
 
@@ -63,7 +60,7 @@ public:
     */
     virtual void operator()(goal_ref const & in, goal_ref_buffer& result) = 0;
 
-    virtual void collect_statistics(statistics & st) const { }
+    virtual void collect_statistics(statistics& st) const {  }
     virtual void reset_statistics() {}
     virtual void cleanup() = 0;
     virtual void reset() { cleanup(); }
@@ -77,6 +74,10 @@ public:
 
     static void checkpoint(ast_manager& m);
 
+    void register_on_clause(void* ctx, user_propagator::on_clause_eh_t& on_clause) override {
+        throw default_exception("tactic does not support clause logging");
+    }
+
     void user_propagate_init(
         void* ctx,
         user_propagator::push_eh_t& push_eh,
@@ -112,17 +113,29 @@ public:
 
 void report_tactic_progress(char const * id, unsigned val);
 
+class statistics_report {
+    tactic* m_tactic = nullptr;
+    std::function<void(statistics& st)> m_collector;
+public:
+    statistics_report(tactic& t):m_tactic(&t) {}
+    statistics_report(std::function<void(statistics&)>&& coll): m_collector(std::move(coll)) {}
+    ~statistics_report();
+};
+
 class skip_tactic : public tactic {
 public:
     void operator()(goal_ref const & in, goal_ref_buffer& result) override;
     void cleanup() override {}
     tactic * translate(ast_manager & m) override { return this; } 
     char const* name() const override { return "skip"; }
+    void collect_statistics(statistics& st) const override {}
+    void user_propagate_initialize_value(expr* var, expr* value) override { }
 };
 
 tactic * mk_skip_tactic();
 tactic * mk_fail_tactic();
 tactic * mk_fail_if_undecided_tactic();
+tactic*  mk_lazy_tactic(ast_manager& m, params_ref const& p, std::function<tactic*(ast_manager& m, params_ref const& p)>);
 
 /*
   ADD_TACTIC("skip", "do nothing tactic.", "mk_skip_tactic()")
