@@ -21,7 +21,7 @@ static euf::enode* get_node(euf::egraph& g, arith_util& a, expr* e) {
     for (expr* arg : *to_app(e))
         args.push_back(get_node(g, a, arg));
     n = g.mk(e, 0, args.size(), args.data());
-    g.add_th_var(n, s_var++, a.get_family_id());
+    g.add_th_var(n, ++s_var, a.get_family_id());
     return n;
 }
 
