@@ -32,7 +32,7 @@ static void tst1() {
         m.set(b, -33);
         std::cout << "a: " << a << ", b: " << b << "\n";
         std::cout << "a*b: " << a*b << "\n";
-        for (unsigned i = 0; i < 100; i++) {
+        for (unsigned i = 0; i < 100; ++i) {
             a = a*a;
             std::cout << i << ": " << a << "\n";
         }
@@ -155,7 +155,7 @@ MK_BIN_OP(div);
 
 #define MK_BIN_RANDOM_TST(OP)                                           \
     static void tst_ ## OP(unsigned N, unsigned max, unsigned prec = 2, bool is_div = false) { \
-    for (unsigned i = 0; i < N; i++) {                                  \
+    for (unsigned i = 0; i < N; ++i) {                                  \
         int n1 = rand() % max;                                          \
         int d1 = rand() % max + 1;                                      \
         int n2 = rand() % max;                                          \
@@ -250,7 +250,7 @@ static void tst_set64(unsigned N, unsigned prec) {
     ENSURE(fm.is_uint64(a));
     ENSURE(!fm.is_int64(a));
 
-    for (unsigned i = 0; i < N; i++) {
+    for (unsigned i = 0; i < N; ++i) {
         {
             uint64_t v = (static_cast<uint64_t>(rand()) << 32) + static_cast<uint64_t>(rand()); 
             fm.set(a, v);
@@ -281,14 +281,14 @@ static void tst_capacity(unsigned prec = 2) {
     mpff_manager m(prec);
     scoped_mpff_vector v(m);
     scoped_mpff a(m);
-    for (unsigned i = 0; i < 50000; i++) {
+    for (unsigned i = 0; i < 50000; ++i) {
         m.set(a, i);
         v.push_back(a);
         ENSURE(m.is_int(v.back()));
         ENSURE(m.is_int64(v.back()));
         ENSURE(m.is_uint64(v.back()));
     }
-    for (unsigned i = 0; i < 50000; i++) {
+    for (unsigned i = 0; i < 50000; ++i) {
         ENSURE(m.get_int64(v[i]) == i);
     }
 }
@@ -486,7 +486,7 @@ static void tst_limits(unsigned prec) {
     ENSURE(!m.is_plus_epsilon(a));
     ENSURE(m.is_minus_epsilon(a));
     
-    for (unsigned i = 0; i < 2; i++) {
+    for (unsigned i = 0; i < 2; ++i) {
         m.set_rounding(i == 0);
         
         m.set_plus_epsilon(a);
