@@ -22,13 +22,13 @@ Revision History:
 static void tst1() {
     svector<int> v1;
     ENSURE(v1.empty());
-    for (unsigned i = 0; i < 1000; i++) {
+    for (unsigned i = 0; i < 1000; ++i) {
         v1.push_back(i + 3);
         ENSURE(static_cast<unsigned>(v1[i]) == i + 3);
         ENSURE(v1.capacity() >= v1.size());
         ENSURE(!v1.empty());
     }
-    for (unsigned i = 0; i < 1000; i++) {
+    for (unsigned i = 0; i < 1000; ++i) {
         ENSURE(static_cast<unsigned>(v1[i]) == i + 3);
     }
     svector<int>::iterator it = v1.begin();
@@ -36,7 +36,7 @@ static void tst1() {
     for (int i = 0; it != end; ++it, ++i) {
         ENSURE(*it == i + 3);
     }
-    for (unsigned i = 0; i < 1000; i++) {
+    for (unsigned i = 0; i < 1000; ++i) {
         ENSURE(static_cast<unsigned>(v1.back()) == 1000 - i - 1 + 3);
         ENSURE(v1.size() == 1000 - i);
         v1.pop_back();
