@@ -22,6 +22,7 @@ Revision History:
 #pragma once
 
 #include <cstddef>
+#include <span>
 #include "util/memory_manager.h"
 
 template<typename T, bool CallDestructors=true, unsigned INITIAL_SIZE=16>
@@ -97,7 +98,7 @@ public:
     }
 
     buffer(unsigned sz, const T & elem) {
-        for (unsigned i = 0; i < sz; i++) {
+        for (unsigned i = 0; i < sz; ++i) {
             push_back(elem);
         }
         SASSERT(size() == sz);
@@ -192,12 +193,17 @@ public:
         return m_buffer;
     }
 
-    void append(unsigned n, T const * elems) {
-        for (unsigned i = 0; i < n; i++) {
-            push_back(elems[i]);
+    void append(std::span<T const> elems) {
+        for (auto const& elem : elems) {
+            push_back(elem);
         }
     }
 
+    // Backward compatibility overload
+    void append(unsigned n, T const * elems) {
+        append(std::span<T const>(elems, n));
+    }
+
     void append(const buffer& source) {
         append(source.size(), source.data());
     }
@@ -230,12 +236,12 @@ public:
     void resize(unsigned nsz, const T & elem=T()) {
         unsigned sz = size();
         if (nsz > sz) {
-            for (unsigned i = sz; i < nsz; i++) {
+            for (unsigned i = sz; i < nsz; ++i) {
                 push_back(elem);
             }
         }
         else if (nsz < sz) {
-            for (unsigned i = nsz; i < sz; i++) {
+            for (unsigned i = nsz; i < sz; ++i) {
                 pop_back();
             }
         }
@@ -245,7 +251,7 @@ public:
     void shrink(unsigned nsz) {
         unsigned sz = size();
         SASSERT(nsz <= sz);
-        for (unsigned i = nsz; i < sz; i++)
+        for (unsigned i = nsz; i < sz; ++i)
             pop_back();
         SASSERT(size() == nsz);
     }
@@ -265,11 +271,16 @@ public:
 template<typename T, unsigned INITIAL_SIZE=16>
 class ptr_buffer : public buffer<T *, false, INITIAL_SIZE> {
 public:
-    void append(unsigned n, T * const * elems) {
-        for (unsigned i = 0; i < n; i++) {
-            this->push_back(elems[i]);
+    void append(std::span<T * const> elems) {
+        for (auto elem : elems) {
+            this->push_back(elem);
         }
     }
+
+    // Backward compatibility overload
+    void append(unsigned n, T * const * elems) {
+        append(std::span<T * const>(elems, n));
+    }
 };
 
 template<typename T, unsigned INITIAL_SIZE=16>
