@@ -20,13 +20,13 @@ Notes:
 
 class common_msgs {
 public:
-    static char const * g_canceled_msg;
-    static char const * g_max_memory_msg;
-    static char const * g_max_scopes_msg;
-    static char const * g_max_steps_msg;
-    static char const * g_max_frames_msg;
-    static char const * g_no_proofs_msg;
-    static char const * g_max_resource_msg;
+    static char const g_canceled_msg[];
+    static char const g_max_memory_msg[];
+    static char const g_max_scopes_msg[];
+    static char const g_max_steps_msg[];
+    static char const g_max_frames_msg[];
+    static char const g_no_proofs_msg[];
+    static char const g_max_resource_msg[];
 };
 
 #define Z3_CANCELED_MSG      common_msgs::g_canceled_msg
