@@ -16,8 +16,7 @@ Author:
 Revision History:
 
 --*/
-#ifndef ERROR_CODES_H_
-#define ERROR_CODES_H_
+#pragma once
 
 #define ERR_OK                  0
 #define ERR_MEMOUT              101
@@ -35,5 +34,4 @@ Revision History:
 #define ERR_ALLOC_EXCEEDED      113
 #define ERR_UNREACHABLE         114
 
-#endif /* ERROR_CODES_H_ */
 
