@@ -28,6 +28,7 @@ Revision History:
 #include <functional>
 #include <algorithm>
 #include <iterator>
+#include <span>
 
 #ifndef SIZE_MAX
 #define SIZE_MAX std::numeric_limits<std::size_t>::max()
@@ -79,14 +80,14 @@ static_assert(sizeof(int64_t) == 8, "64 bits");
 # define Z3_fallthrough
 #endif
 
-inline bool is_power_of_two(unsigned v) { return !(v & (v - 1)) && v; }
+static inline bool is_power_of_two(unsigned v) { return !(v & (v - 1)) && v; }
 
 /**
    \brief Return the next power of two that is greater than or equal to v.
    
    \warning This function returns 0 for v == 0.
 */
-inline unsigned next_power_of_two(unsigned v) {
+static inline unsigned next_power_of_two(unsigned v) {
     v--;
     v |= v >> 1;
     v |= v >> 2;
@@ -114,7 +115,7 @@ static inline unsigned get_num_1bits(unsigned v) {
 #ifdef Z3DEBUG
     unsigned c;
     unsigned v1 = v;
-    for (c = 0; v1; c++) {
+    for (c = 0; v1; ++c) {
         v1 &= v1 - 1; 
     }
 #endif
@@ -133,7 +134,7 @@ static inline unsigned get_num_1bits(uint64_t v) {
 #ifdef Z3DEBUG
     unsigned c;
     uint64_t v1 = v;
-    for (c = 0; v1; c++) {
+    for (c = 0; v1; ++c) {
         v1 &= v1 - 1; 
     }
 #endif
@@ -311,7 +312,7 @@ public:
 
 template<typename T>
 bool compare_arrays(const T * array1, const T * array2, unsigned size) {
-    for (unsigned i = 0; i < size; i++) {
+    for (unsigned i = 0; i < size; ++i) {
         if (!(array1[i] == array2[i])) {
             return false;
         }
@@ -344,6 +345,7 @@ public:
     }
 
     void set_seed(unsigned s) { m_data = s; }
+    unsigned get_seed() const { return m_data; }
 
     int operator()() {
         return ((m_data = m_data * 214013L + 2531011L) >> 16) & 0x7fff; 
@@ -360,14 +362,20 @@ public:
 };
 
 template<typename T>
-void shuffle(unsigned sz, T * array, random_gen & gen) {
-    int n = sz;
-    while (--n > 0) {
+void shuffle(std::span<T> array, random_gen & gen) {
+    auto n = array.size();
+    while (n-- > 0) {
         int k = gen() % (n + 1);
         std::swap(array[n], array[k]);
     }
 }
 
+// Backward compatibility overload
+template<typename T>
+void shuffle(unsigned sz, T * array, random_gen & gen) {
+    shuffle(std::span<T>(array, sz), gen);
+}
+
 void fatal_error(int error_code);
 
 void set_fatal_error_handler(void (*pfn)(int error_code));
