@@ -170,7 +170,7 @@ public:
     }
 
     vector(SZ s, T const * data) {
-        for (SZ i = 0; i < s; i++) {
+        for (SZ i = 0; i < s; ++i) {
             push_back(data[i]);
         }
     }
@@ -195,7 +195,7 @@ public:
         }
         if (size() != other.size())
             return false;
-        for (unsigned i = 0; i < size(); i++) {
+        for (unsigned i = 0; i < size(); ++i) {
             if ((*this)[i] != other[i])
                 return false;
         }
@@ -405,7 +405,14 @@ public:
         if (CallDestructors) {
             back().~T(); 
         }
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Warray-bounds"
+#endif
         reinterpret_cast<SZ *>(m_data)[SIZE_IDX]--; 
+#if defined(__GNUC__) && !defined(__clang__)
+#pragma GCC diagnostic pop
+#endif
     }
 
     vector& push_back(T const & elem) {
